SELECT 10/aiomysql - Criterion.rs

## SELECT 10/aiomysql

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0061448 | 0.0063627 | 0.0061125
Mean | 16.858 ms | 17.057 ms | 17.271 ms
Std. Dev. | 864.21 µs | 1.0606 ms | 1.2302 ms
Median | 16.452 ms | 16.694 ms | 17.014 ms
MAD | 514.77 µs | 799.53 µs | 1.0834 ms

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.